@@ -1,16 +1,16 @@
 use super::*;
-use crate::util::{ATTRIBUTE_KEY, END_LINE};
+use crate::lexer::END_LINE;
+use crate::util::ATTRIBUTE_KEY;
 
 use std::io::BufReader;
 use std::iter::Iterator;
 
-const EXAMPLE_ATTR_EXTMAP1: &'static str = "extmap:1 http://example.com/082005/ext.htm#ttime";
-const EXAMPLE_ATTR_EXTMAP2: &'static str =
+const EXAMPLE_ATTR_EXTMAP1: &str = "extmap:1 http://example.com/082005/ext.htm#ttime";
+const EXAMPLE_ATTR_EXTMAP2: &str =
     "extmap:2/sendrecv http://example.com/082005/ext.htm#xmeta short";
-const FAILING_ATTR_EXTMAP1: &'static str =
+const FAILING_ATTR_EXTMAP1: &str =
     "extmap:257/sendrecv http://example.com/082005/ext.htm#xmeta short";
-const FAILING_ATTR_EXTMAP2: &'static str =
-    "extmap:2/blorg http://example.com/082005/ext.htm#xmeta short";
+const FAILING_ATTR_EXTMAP2: &str = "extmap:2/blorg http://example.com/082005/ext.htm#xmeta short";
 
 #[test]
 fn test_extmap() -> Result<()> {
@@ -53,15 +53,15 @@ fn test_extmap() -> Result<()> {
 
 #[test]
 fn test_transport_cc_extmap() -> Result<()> {
-    //a=extmap:<value>["/"<direction>] <URI> <extensionattributes>
-    //a=extmap:3 http://www.ietf.org/id/draft-holmer-rmcat-transport-wide-cc-extensions-01
+    // a=extmap:<value>["/"<direction>] <URI> <extensionattributes>
+    // a=extmap:3 http://www.ietf.org/id/draft-holmer-rmcat-transport-wide-cc-extensions-01
     let uri = Some(Url::parse(
         "http://www.ietf.org/id/draft-holmer-rmcat-transport-wide-cc-extensions-01",
     )?);
     let e = ExtMap {
         value: 3,
         uri,
-        direction: Direction::DirectionUnknown,
+        direction: Direction::Unspecified,
         ext_attr: None,
     };
 
