@@ -1,10 +1,10 @@
 use super::*;
-use crate::common_description::*;
-use crate::media_description::*;
-use crate::session_description::*;
+use crate::description::common::*;
+use crate::description::media::*;
+use crate::description::session::*;
 
 fn get_test_session_description() -> SessionDescription {
-    return SessionDescription{
+    SessionDescription{
         media_descriptions: vec![
             MediaDescription {
                 media_name: MediaName {
@@ -33,7 +33,7 @@ fn get_test_session_description() -> SessionDescription {
             },
 		],
         ..Default::default()
-	};
+	}
 }
 
 #[test]
